@@ -7,7 +7,7 @@
  * #  Verwendung in anderen Programmen bzw. Programmiersprachen benutzt     #
  * #  werden.                                                               #
  * #                                                                        #
- * #  Copyright (C) 2002-2009 Michael Plugge <m.plugge@hs-mannheim.de>      #
+ * #  Copyright (C) 2002-2011 Michael Plugge <m.plugge@hs-mannheim.de>      #
  * #                                                                        #
  * #  Dieses Programm ist freie Software; Sie drfen es unter den           #
  * #  Bedingungen der GNU Lesser General Public License, wie von der Free   #
@@ -44,6 +44,16 @@
 #ifndef KONTO_CHECK_H_INCLUDED
 #define KONTO_CHECK_H_INCLUDED
 
+/* 
+ * ##########################################################################
+ * # Die Berechnungsmethode D1 wird zum 7.3.2011 gendert; wenn das         #
+ * # folgenden Makro auf 1 gesetzt wird, wird die neue Berechnungsmethode   #
+ * # verwendet. Die Methode wird aktuell (30.12.2010) von keiner Bank       #
+ * # benutzt, daher kann der neue Code ohne Probleme schon aktiviert werden.#
+ * ##########################################################################
+ */
+#define METHODE_D1_NEU_2011_03_07 1
+
 /* 
  * ##########################################################################
  * # Fallls das folgende Makro auf 1 gesetzt wird, werden unterschiedliche  #
@@ -373,7 +383,8 @@ extern char *lut2_feld_namen[256];
 #define KTO_CHECK_VALUE_REPLACED                10
 #define OK_UNTERKONTO_POSSIBLE                  11
 #define OK_UNTERKONTO_GIVEN                     12
-#line 219 "konto_check_h.lx"
+#define OK_SLOT_CNT_MIN_USED                    13
+#line 229 "konto_check_h.lx"
 
 #define MAX_BLZ_CNT 30000  /* maximale Anzahl BLZ's in generate_lut() */
 
@@ -443,6 +454,30 @@ typedef struct{
    int c2,d2,a5,p,konto[11];
 } KTO_CHK_CTX;
 
+/*
+ * ##########################################################################
+ * # SLOT_CNT_MIN: Minimale Anzahl Slots fr eine LUT-Daei.                 #
+ * # Dieser Parameter gibt an, wieviele Slots das Inhaltsverzeichnis einer  #
+ * # LUT-Datei mindestens haben soll. Fr jeden Block in der LUT-Datei wird #
+ * # ein Slot im Inhaltsverzeichnis bentigt; bei einer LUT-Datei mit allen #
+ * # Eintrgen (Level 9) sind das 12 Slots, falls zwei Datenstze in der    #
+ * # Datei gehalten werden sollen, 24 (Mindestanzahl!).                     #
+ * #                                                                        #
+ * # Das Slotverzeichnis ist eine relativ einfache Datenstruktur; es        #
+ * # enthlt fr jeden Slot nur drei 4 Byte-Integers (Typ, Offset und       #
+ * # Lnge); daher ist es auch kein Problem, fr das Slotverzeichnis einen  #
+ * # etwas greren Wert zu whlen. Die Datei wird dadurch nur minimal      #
+ * # grer. Die angegebene Anzahl Slots kann nachtrglich nicht mehr       #
+ * # gendert werden, da das Slotverzeichnis am Beginn des Datenblocks      #
+ * # steht und sich bei einer Vergrerung alle Offsets in der Datei ndern #
+ * # wrden; auerdem mten alle Blocks verschoben werden. Es gibt die     #
+ * # Mglichkeit, eine LUT-Datei zu kopieren (mittels copy_lutfile()); bei  #
+ * # dieser Funktion kann eine neue Anzahl Slots angegeben werden.          #
+ * #                                                                        #
+ * ##########################################################################
+ */
+#define SLOT_CNT_MIN 25
+
 /*
  * ##########################################################################
  * # Benutzte Kompressionsbibliothek fr die LUT-Datei. Mgliche Werte:     #
